#!/bin/sh

function print_usage {
    echo "Usage: squeakci [OPTIONS] image"
    echo "Execute all squeak unit tests and output result in testResults subdirectory"
    echo ""
    echo "-s                command used to run squeak vm. Defaults to $squeak_command"
    echo "-h                show this help"
}


function generate_test_package_code {
    echo "CITestRunner new runAllTests.
          SmalltalkImage current snapshot: false andQuit: true" > $test_st_path
}


#################################################################
# Default options                                               #
#################################################################
squeak_command=squeakvm
tmp_dir="/tmp"
test_st_path="$tmp_dir/test-squeak.st"


#################################################################
# Read command line arguments                                   #
#################################################################
NO_ARGS=0
E_OPTERROR=65
if [ $# -eq "$NO_ARGS" ]  
then
    echo "Squeak image missing ! Use squeakci -h to show usage."
    exit $E_OPTERROR
fi


while getopts "p:s:h" Option
do
    case $Option in
	s     ) squeak_command=$OPTARG;;
	h     ) print_usage;;
	*     ) print_usage;;
    esac
done
shift $(($OPTIND - 1))

squeak_image=$1
    
echo "squeakci options:"
echo "squeak_command:     $squeak_command"
echo "squeak_image:       $squeak_image"


#################################################################
# Run tests                                                     #
#################################################################
generate_test_package_code `echo $1|sed "s/\.image//g"`

$squeak_command $squeak_image $test_st_path $package

exit 0